@@ -380,9 +380,9 @@ fgets(buff,128,stdin);
 
 void auto_cal(float *bufptr, int analflag)
 {
-float buf = *bufptr, temp = 0;
+float buf = *bufptr, temp = 0, lowcarbsatfatchangeover = 0.30;
 int i;
-if (options.autocal) buf = average_cals(analflag);
+if (options.autocal) buf = average_cals();
 if (analflag)
  {
  if (food_work.nutrient[PROT_KCAL] > 0 && food_work.nutrient[PROCNT] > 0) options.protcalpergm = food_work.nutrient[PROT_KCAL] / food_work.nutrient[PROCNT];
@@ -475,6 +475,7 @@ if (options.abnuts[FAPU] == 0)
  if (options.abnuts[EPA] != 0) DV[EPA] = options.abnuts[EPA];
  if (options.abnuts[DHA] != 0) DV[DHA] = options.abnuts[DHA];
  temp = DV[OMEGA6] + DV[OMEGA3] - DV[FAPU];
+ if (analflag) temp += food_work.nutrient[FAPU] - food_work.nutrient[OMEGA6] - food_work.nutrient[OMEGA3];
  DV[FAPU] += temp;
  DV[FAMS] -= temp;
  }
@@ -512,12 +513,13 @@ if (options.abnuts[ZN] > 0) DV[ZN] = options.abnuts[ZN];
 if (! options.abnuts[CHO_NONFIB]) DV[CHO_NONFIB] = DV[CHOCDF] - DV[FIBTG] < 0 ? 0 : DV[CHOCDF] - DV[FIBTG];
 else DV[CHO_NONFIB] = options.abnuts[CHO_NONFIB];
 temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm) / DV[ENERC_KCAL];
-if (temp > .32 && options.pcsatfat <= 0 && options.abnuts[FASAT] <= 0 && options.abnuts[FAMS] <= 0) 
+if (temp > lowcarbsatfatchangeover && options.pcsatfat <= 0 && options.abnuts[FASAT] <= 0 && options.abnuts[FAMS] <= 0) 
  {
- temp = (1.04 * DV[FASAT] * temp / .3) - DV[FASAT];
+ temp = (0.3 / lowcarbsatfatchangeover * DV[FASAT] * temp / 0.3) - DV[FASAT];
  DV[FASAT] += temp;
  DV[FAMS] -= temp;
  if (analflag && food_work.nutrient[FASAT] < DV[FASAT])
+ /* if (analflag) */
   {
   temp = (DV[FASAT] + DV[FAMS]) / (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]);
   DV[FASAT] = food_work.nutrient[FASAT] * temp;
@@ -694,9 +696,13 @@ void efa_dynamics()
 {
 int i;
 float temp, temp1, temp_la = 0, temp_aa = 0, hufapct, p3, h3, h6, p6, o;
-float target = 62, epadhalimit, extra_ala;
+float target = 75, epadhalimit = 1.0, extra_ala;
 
-epadhalimit = DV[ENERC_KCAL] * .0069 / 9.02;
+/*
+DV[ALA] = food_work.nutrient[ALA];
+if (DV[ALA] <= 0) DV[ALA] = .00001;
+*/
+if (food_work.nutrient[ALA] > DV[ALA]) DV[ALA] = food_work.nutrient[ALA];
 
 if (options.n6hufa != 0)
  {
@@ -745,6 +751,7 @@ if (food_work.nutrient[EPA] > .02 || food_work.nutrient[DHA] > .02 || food_work.
    if (options.n6hufa > 0 && hufapct < options.n6hufa) break;
    }
   options.abnuts[LA] -= temp_la / 902 * food_work.nutrient[ENERC_KCAL];
+  temp_aa = 902 / food_work.nutrient[ENERC_KCAL] * food_work.nutrient[AA] * (1 - (options.abnuts[LA] / food_work.nutrient[LA]));
   options.abnuts[AA] -= temp_aa / 902 * food_work.nutrient[ENERC_KCAL];
   options.abnuts[OMEGA6] -= (temp_la + temp_aa) / 902 * food_work.nutrient[ENERC_KCAL];
   }
